==> atmelwlandriver-3.3.5.6.tar.bz2: atmelwlandriver/src/apps/winter/Accessor.cpp <==
/* Accessor.cpp */
/*******************************************************************************************
	Copyright 2002-2003 ATMEL Corporation.

	This file is part of ATMEL Wireless LAN Drivers.

	ATMEL Wireless LAN Drivers is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	ATMEL Wireless LAN Drivers is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with ATMEL Wireless LAN Drivers; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*******************************************************************************************/

#include "Accessor.h"
#include "WinterModel.h"
#include "WinterApp.h"
#include "WinterTimer.h"
#include "Device.h"
#include "Profile.h"
#include "WinterConfig.h"
#include "HRStrings.h"


CAccessor::CAccessor( )
{
}

CAccessor::~CAccessor( )
{
}

void *CAccessor::Access( AId_t aid )
{
	void *ret = NULL;

	switch( aid )
	{
		case AID_FRAME:
			ret = wxGetApp().GetTopWindow( );
			break;
		case AID_TIMER:
			ret = CWinterTimerSingleton::Get( );
			break;
		case AID_DEVICEMANAGER:
			ret = CVnetDeviceManagerSingleton::Get( );
			break;
		case AID_PROFILEMANAGER:
			ret = CWinterProfileManagerSingleton::Get( );
			break;
		case AID_STRINGSPROVIDER:
			ret = CWinterStringsProviderSingleton::Get( );
			break;
		case AID_CONFIG:
			ret = CWinterConfigSingleton::Get( );
			break;

		// Multiple devices specific
		case AID_CURRENTDEVICE:
			// TODO: Read the value of the combobox to determine which is the current device.
			ret = ( ( CVnetDeviceManager * ) CAccessor::Access( AID_DEVICEMANAGER ) )->GetDevice( 0 );
			break;
		case AID_CURRENTMODEL:
			ret = ( ( CVnetDeviceBase * ) CAccessor::Access( AID_CURRENTDEVICE ) )->GetModel( );
			break;

		default:
			// This should never happen, in theory. A dummy comment!
			// One more dummy comment!
			break;
	}

	return ret;
}

==> atmelwlandriver-3.4.1.0.tar.bz2: atmelwlandriver/src/apps/winter/Accessor.cpp <==
/* Accessor.cpp */
/*******************************************************************************************
	Copyright 2002-2003 ATMEL Corporation.

	This file is part of ATMEL Wireless LAN Drivers.

	ATMEL Wireless LAN Drivers is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	ATMEL Wireless LAN Drivers is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with ATMEL Wireless LAN Drivers; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*******************************************************************************************/

#include "Accessor.h"
#include "WinterModel.h"
#include "WinterApp.h"
#include "WinterTimer.h"
#include "Device.h"
#include "Profile.h"
#include "WinterConfig.h"
#include "HRStrings.h"
#include "WinterFrame.h"


CAccessor::CAccessor( )
{
}

CAccessor::~CAccessor( )
{
}

void *CAccessor::Access( AId_t aid )
{
	void *ret = NULL;

	switch( aid )
	{
		case AID_FRAME:
			ret = wxGetApp().GetTopWindow( );
			break;
		case AID_TIMER:
			ret = CWinterTimerSingleton::Get( );
			break;
		case AID_DEVICEMANAGER:
			ret = CVnetDeviceManagerSingleton::Get( );
			break;
		case AID_PROFILEMANAGER:
			ret = CWinterProfileManagerSingleton::Get( );
			break;
		case AID_STRINGSPROVIDER:
			ret = CWinterStringsProviderSingleton::Get( );
			break;
		case AID_CONFIG:
			ret = CWinterConfigSingleton::Get( );
			break;

		// Multiple devices specific
		case AID_CURRENTDEVICE:
			// TODO: Read the value of the combobox to determine which is the current device.
			ret = ( ( CVnetDeviceManager * ) CAccessor::Access( AID_DEVICEMANAGER ) )->GetDevice( 
				((CWinterFrame*)CAccessor::Access(AID_FRAME))->GetDeviceIndex());
			break;
		case AID_CURRENTMODEL:
			ret = ( ( CVnetDeviceBase * ) CAccessor::Access( AID_CURRENTDEVICE ) )->GetModel( );
			break;

		default:
			// This should never happen, in theory. A dummy comment!
			// One more dummy comment!
			break;
	}

	return ret;
}
